# Persuading to Prepare for Quitting Smoking with a Virtual Coach: Using States and User Characteristics to Predict Behavior
## Analysis Steps


**Author**: Nele Albers
**Date**: February 2023


This file is meant to guide you through reproducing our analysis from the paper "Persuading to Prepare to Quit Smoking with a Virtual Coach: Using States and User Characteristics to Predict Behavior" by Nele Albers, Mark A. Neerincx, and Willem-Paul Brinkman.


### Steps to Reproduce Analysis

The reproduction of our code is based on Docker and Jupyter Notebook. Take the following steps:
1. If you want to recreate the extraction of RL-samples of the form <s, a, r, s'> and user characteristics from the gathered data, run the file extract_RL_samples.py from the root directory. This will create the files "rl_samples_list_binary_activities.csv" and "all_states.csv" in the Data-folder. If you want to skip this step, a version of these files computed by us is already in the Data-folder.
2. Make sure that you have Docker installed. You can check whether you do by running `docker -v`.
3. Now choose from the following two options:
   - In the directory of this README-file, build the Docker image via `docker build . -t gbna4/aamas_persuasion_states_char`. 
   - In the directory of this README-file, pull the Docker image from Dockerhub via `docker pull gbna4/aamas_persuasion_states_char`. 
4. Run the Docker container via `docker run -p 8888:8888 -e JUPYTER_ENABLE_LAB=yes -v <this_working_directory>:/home/jovyan/work gbna4/aamas_persuasion_states_char`, where `<this_working_directory>` is the path to the directory that this README-file is in.
5. Go to one of the links presented in the terminal upon running the Docker container to access Jupyter Notebook.
6. Open the "work"-folder in Jupyter Notebook.
7. There is one notebook for each of the six research questions (e.g., "analysis_q1.ipynb" for question Q1). In addition, there is the notebook "participant_characteristics.ipynb" to reproduce the participant characteristics reported in the Appendix.


### Explanation of Files and Folders

This directory contains the following files and folders:
- Data: Folder with the pre-processed data needed for the analyses.
- Figures: All figures from the paper as created by us. Running the corresponding parts from the notebooks will recreate these figures.
- Intermediate_Results: Intermediate results for more time-intensive computations for question Q6. Running the corresponding steps in the notebook for Q6 will recreate these intermediate results.
- analysis_q1.ipynb: Notebook to reproduce our results for question Q1, including Figure 1.
- analysis_q2.ipynb: Notebook to reproduce our results for question Q2, including Figure 2.
- analysis_q3.ipynb: Notebook to reproduce our results for question Q3, including Figure 3 and 4.
- analysis_q4.ipynb: Notebook to reproduce our results for question Q4, including Figure 5.
- analysis_q5.ipynb: Notebook to reproduce our results for question Q5, including Figure 6.
- analysis_q6.ipynb: Notebook to reproduce our results for question Q6.
- Compute_RL_Actions.py: Code for computing the mean reward per action.
- Compute_RL_QValues.py: Code for computing Q-values and dynamics for our MDP.
- Compute_RL_Similarity_Weighted_All.py: Code for computing Q-values and dynamics for our MDP when weighting all samples based on user similarity.
- Compute_RL_Similarity_Weighted_Most_Similar.py: Code for computing Q-values and dynamics for our MDP when increasing the frequency of samples from the most similar people.
- Dockerfile: To create a Docker image for a Docker container to run the analyses.
- participant_characteristics.ipynb: Notebook to reproduce our participant characteristics reported in the Appendix.
- README.md/README.pdf: This README-file.
- Utils.py: Some common functions needed for the Reinforcement Learning (RL)-related computations.
